@@ -1,5 +1,5 @@
 package MooX::Role::POE::Emitter;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moo::Role;
 
@@ -133,7 +133,7 @@ sub _start_emitter {
 
         'emit'        => '__emitter_notify',
 
-        '_default'    => '_emitter_default',
+        '_default'    => '__emitter_disp_default',
       },
 
       $self => [ qw/
@@ -275,8 +275,11 @@ sub _trigger_object_states {
   my @disallowed = qw/
     _start
     _stop
+    _default
     register
     unregister
+    subscribe
+    unsubscribe
   /;
 
   for (my $i=1; $i <= (scalar(@$states) - 1 ); $i+=2 ) {
@@ -371,7 +374,7 @@ sub __emitter_notify {
   my $eat = $self->_pluggable_process( 'NOTIFY', $event, \@args );
 
   unless ($eat == EAT_ALL) {
-    ## Notify registered sessions.
+    ## Notify subscribed sessions.
     $kernel->call( $_, $meth, @args )
       for keys %sessions;
   }
@@ -402,7 +405,7 @@ sub __emitter_start {
     $self->__incr_ses_refc( $s_id );
     $self->__reg_ses_id( $s_id );
 
-    ## register parent session for all notification events.
+    ## subscribe parent session to all notification events.
     $self->__emitter_reg_events->{ 'all' }->{ $s_id } = 1;
 
     ## Detach child session.
@@ -414,10 +417,26 @@ sub __emitter_start {
   $self
 }
 
-sub _emitter_default {
+sub __emitter_disp_default {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   my ($event, $args) = @_[ARG0, ARG1];
 
+  if (ref $event eq 'CODE') {
+    ## Anonymous coderef callback.
+    ## Cute trick from dngor:
+    splice @_, ARG0, 2, @$args;
+    $_[STATE] = $event;
+    goto $event
+  } else {
+    ## Ugly? Yes, but we can retain compat w/ _emitter_default override:
+    goto &_emitter_default
+  }
+}
+
+sub _emitter_default {
+  my ($kernel, $self) = @_[KERNEL, OBJECT];
+  my ($event, $args)  = @_[ARG0, ARG1];
+
   ## Session received an unknown event.
   ## Dispatch it to any appropriate P_$event handlers.
 
@@ -705,6 +724,11 @@ B<_start_emitter()> should be called on our object to spawn the actual
 L<POE::Session>. It takes no arguments and should be called after the 
 object has been configured.
 
+=head3 _shutdown_emitter
+
+B<_shutdown_emitter()> must be called to terminate the Emitter's 
+L<POE::Session>.
+
 =head2 Listening sessions
 
 =head3 Session event subscription
@@ -755,19 +779,21 @@ The emitter's L<POE::Session> provides a '_default' handler that
 redispatches unknown POE-delivered events to L</process> 
 (except for events prefixed with '_', which are reserved).
 
-As a side-effect, subscribing the 'self' Session to some events (or 'all') 
-will cause unhandled L</NOTIFY events> to be redispatched as L</PROCESS 
-events>.
-
-To change this behavior, override the method '_emitter_default' in your 
-class:
+You can change this behavior by overriding '_emitter_default' -- here's a 
+direct adaption of the example from L<POE::Component::Syndicator>:
 
   use Moo;
+  use POE;
   with 'MooX::Role::POE::Emitter';
   around '_emitter_default' => sub {
     my $orig = shift;
-    ## Drop unhandled events on the floor, for example.
-    return
+    my ($kernel, $self) = @_[KERNEL, OBJECT];
+    my ($event, $args)  = @_[ARG0, ARG1];
+
+    ## process(), then do something else, for example
+    return if $self->process( $event, @$args ) == EAT_ALL;
+
+    . . .
   };
 
 =head2 EAT values
@@ -848,8 +874,15 @@ managing timers within the context of the emitter's L<POE::Session>.
 
   $self->yield( $poe_event, @args );
 
-Provides an interface to L<POE::Kernel>'s yield() method, dispatching POE 
-events within the context of the emitter's session.
+Provides an interface to L<POE::Kernel>'s yield/post() method, dispatching 
+POE events within the context of the emitter's session.
+
+The event can be either a named event/state or an anonymous coderef:
+
+  $self->yield( sub {
+    my ($kernel, @args) = @_[KERNEL, ARG0 .. $#_];
+    . . .
+  }, $some, $args );
 
 =head3 call
 
@@ -868,12 +901,23 @@ The synchronous counterpart to L</yield>.
 Set a timer in the context of the emitter's L<POE::Session>. Returns the 
 POE alarm ID.
 
+The event can be either a named event/state or an anonymous coderef (see 
+L</yield>).
+
+A prefixed (L</event_prefix>) 'timer_set' event is emitted when a timer is 
+set. Arguments are the alarm ID, the event name or coderef, the delay time, 
+and any event parameters, respectively.
+
 =head3 timer_del
 
   $self->timer_del( $alarm_id );
 
 Clears a pending L</timer>.
 
+A prefixed (L</event_prefix>) 'timer_deleted' event is emitted when a timer 
+is deleted. Arguments are the removed alarm ID, the event name or coderef, 
+and any event parameters, respectively.
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
